package com.zehong.system.service;

import java.util.List;
import com.zehong.system.domain.TSafeInspectLedger;

/**
 * 安全检查台账Service接口
 * 
 * @author zehong
 * @date 2026-03-27
 */
public interface ITSafeInspectLedgerService 
{
    /**
     * 查询安全检查台账
     * 
     * @param inspectId 安全检查台账ID
     * @return 安全检查台账
     */
    public TSafeInspectLedger selectTSafeInspectLedgerById(Long inspectId);

    /**
     * 查询安全检查台账列表
     * 
     * @param tSafeInspectLedger 安全检查台账
     * @return 安全检查台账集合
     */
    public List<TSafeInspectLedger> selectTSafeInspectLedgerList(TSafeInspectLedger tSafeInspectLedger);

    /**
     * 新增安全检查台账
     * 
     * @param tSafeInspectLedger 安全检查台账
     * @return 结果
     */
    public int insertTSafeInspectLedger(TSafeInspectLedger tSafeInspectLedger);

    /**
     * 修改安全检查台账
     * 
     * @param tSafeInspectLedger 安全检查台账
     * @return 结果
     */
    public int updateTSafeInspectLedger(TSafeInspectLedger tSafeInspectLedger);

    /**
     * 批量删除安全检查台账
     * 
     * @param inspectIds 需要删除的安全检查台账ID
     * @return 结果
     */
    public int deleteTSafeInspectLedgerByIds(Long[] inspectIds);

    /**
     * 删除安全检查台账信息
     * 
     * @param inspectId 安全检查台账ID
     * @return 结果
     */
    public int deleteTSafeInspectLedgerById(Long inspectId);
}
